@@ -17,12 +17,14 @@
 #
 # ------------------------------------------------------------------------------
 
-"""This module contains the implementation of an Autonomous Economic Agent."""
+"""This module contains the implementation of an autonomous economic agent (AEA)."""
+
 import logging
 from asyncio import AbstractEventLoop
 from typing import List, Optional, cast
 
 from aea.agent import Agent
+from aea.configurations.base import PublicId
 from aea.connections.base import Connection
 from aea.context.base import AgentContext
 from aea.crypto.ledger_apis import LedgerApis
@@ -31,13 +33,17 @@ from aea.decision_maker.base import DecisionMaker
 from aea.identity.base import Identity
 from aea.mail.base import Envelope
 from aea.protocols.default.message import DefaultMessage
-from aea.registries.base import Filter, Resources
-from aea.skills.error import ERROR_SKILL_ID
+from aea.registries.filter import Filter
+from aea.registries.resources import Resources
 from aea.skills.error.handlers import ErrorHandler
 from aea.skills.tasks import TaskManager
 
 logger = logging.getLogger(__name__)
 
+ERROR_SKILL_ID = PublicId(
+    "fetchai", "error", "0.1.0"
+)  # TODO; specify error handler in config
+
 
 class AEA(Agent):
     """This class implements an autonomous economic agent."""
@@ -60,14 +66,14 @@ class AEA(Agent):
 
         :param identity: the identity of the agent
         :param connections: the list of connections of the agent.
-        :param loop: the event loop to run the connections.
         :param wallet: the wallet of the agent.
-        :param ledger_apis: the ledger apis of the agent.
-        :param resources: the resources of the agent.
+        :param ledger_apis: the APIs the agent will use to connect to ledgers.
+        :param resources: the resources (protocols and skills) of the agent.
+        :param loop: the event loop to run the connections.
         :param timeout: the time in (fractions of) seconds to time out an agent between act and react
-        :param is_debug: if True, run the agent in debug mode.
+        :param is_debug: if True, run the agent in debug mode (does not connect the multiplexer).
         :param is_programmatic: if True, run the agent in programmatic mode (skips loading of resources from directory).
-        :param max_reactions: the processing rate of messages per iteration.
+        :param max_reactions: the processing rate of envelopes per tick (i.e. single loop).
 
         :return: None
         """
@@ -77,14 +83,11 @@ class AEA(Agent):
             loop=loop,
             timeout=timeout,
             is_debug=is_debug,
-            is_programmatic=is_programmatic,
         )
 
         self.max_reactions = max_reactions
         self._task_manager = TaskManager()
-        self._decision_maker = DecisionMaker(
-            self.name, self.max_reactions, self.outbox, wallet, ledger_apis
-        )
+        self._decision_maker = DecisionMaker(identity, wallet, ledger_apis)
         self._context = AgentContext(
             self.identity,
             ledger_apis,
@@ -106,7 +109,7 @@ class AEA(Agent):
 
     @property
     def context(self) -> AgentContext:
-        """Get context."""
+        """Get (agent) context."""
         return self._context
 
     @property
@@ -119,11 +122,6 @@ class AEA(Agent):
         """Set resources."""
         self._resources = resources
 
-    @property
-    def filter(self) -> Filter:
-        """Get filter."""
-        return self._filter
-
     @property
     def task_manager(self) -> TaskManager:
         """Get the task manager."""
@@ -133,10 +131,15 @@ class AEA(Agent):
         """
         Set up the agent.
 
+        Performs the following:
+
+        - loads the resources (unless in programmatic mode)
+        - starts the task manager
+        - starts the decision maker
+        - calls setup() on the resources
+
         :return: None
         """
-        if not self.is_programmatic:
-            self.resources.load(self.context)
         self.task_manager.start()
         self.decision_maker.start()
         self.resources.setup()
@@ -145,14 +148,25 @@ class AEA(Agent):
         """
         Perform actions.
 
+        Calls act() of each active behaviour.
+
         :return: None
         """
-        for behaviour in self.filter.get_active_behaviours():
+        for behaviour in self._filter.get_active_behaviours():
             behaviour.act_wrapper()
 
     def react(self) -> None:
         """
-        React to incoming events (envelopes).
+        React to incoming envelopes.
+
+        Gets up to max_reactions number of envelopes from the inbox and
+        handles each envelope, which entailes:
+
+        - fetching the protocol referenced by the envelope, and
+        - returning an envelope to sender if the protocol is unsupported, using the error handler, or
+        - returning an envelope to sender if there is a decoding error, using the error handler, or
+        - returning an envelope to sender if no active handler is available for the specified protocol, using the error handler, or
+        - handling the message recovered from the envelope with all active handlers for the specified protocol.
 
         :return: None
         """
@@ -171,10 +185,10 @@ class AEA(Agent):
         :return: None
         """
         logger.debug("Handling envelope: {}".format(envelope))
-        protocol = self.resources.protocol_registry.fetch(envelope.protocol_id)
+        protocol = self.resources.get_protocol(envelope.protocol_id)
 
         # TODO make this working for different skill/protocol versions.
-        error_handler = self.resources.handler_registry.fetch_by_protocol_and_skill(
+        error_handler = self.resources.get_handler(
             DefaultMessage.protocol_id, ERROR_SKILL_ID,
         )
 
@@ -193,7 +207,9 @@ class AEA(Agent):
             logger.warning("Decoding error. Exception: {}".format(str(e)))
             return
 
-        handlers = self.filter.get_active_handlers(protocol.id, envelope.context)
+        handlers = self._filter.get_active_handlers(
+            protocol.public_id, envelope.context
+        )
         if len(handlers) == 0:
             if error_handler is not None:
                 error_handler.send_unsupported_skill(envelope)
@@ -206,17 +222,24 @@ class AEA(Agent):
         """
         Update the current state of the agent.
 
+        Handles the internal messages from the skills to the decision maker.
+
         :return None
         """
-        self.filter.handle_internal_messages()
+        self._filter.handle_internal_messages()
 
     def teardown(self) -> None:
         """
         Tear down the agent.
 
+        Performs the following:
+
+        - stops the decision maker
+        - stops the task manager
+        - tears down the resources.
+
         :return: None
         """
         self.decision_maker.stop()
         self.task_manager.stop()
-        if self._resources is not None:
-            self._resources.teardown()
+        self.resources.teardown()
