@@ -25,6 +25,7 @@ import shutil
 import sys
 import time
 from pathlib import Path
+from typing import cast
 
 import click
 
@@ -33,13 +34,14 @@ from aea.cli.add import add
 from aea.cli.common import (
     AgentDirectory,
     Context,
+    _verify_or_create_private_keys,
+    check_aea_project,
     logger,
-    pass_ctx,
-    try_to_load_agent_config,
 )
 from aea.cli.config import config
 from aea.cli.create import create
 from aea.cli.fetch import fetch
+from aea.cli.fingerprint import fingerprint
 from aea.cli.generate import generate
 from aea.cli.init import init
 from aea.cli.install import install
@@ -47,10 +49,12 @@ from aea.cli.launch import launch
 from aea.cli.list import list as _list
 from aea.cli.loggers import simple_verbosity_option
 from aea.cli.login import login
+from aea.cli.logout import logout
 from aea.cli.publish import publish
 from aea.cli.push import push
+from aea.cli.register import register
 from aea.cli.remove import remove
-from aea.cli.run import _verify_or_create_private_keys, run
+from aea.cli.run import run
 from aea.cli.scaffold import scaffold
 from aea.cli.search import search
 from aea.configurations.base import DEFAULT_AEA_CONFIG_FILE
@@ -73,18 +77,28 @@ FUNDS_RELEASE_TIMEOUT = 10
 @click.group(name="aea")
 @click.version_option(aea.__version__, prog_name="aea")
 @simple_verbosity_option(logger, default="INFO")
+@click.option(
+    "--skip-consistency-check",
+    "skip_consistency_check",
+    is_flag=True,
+    required=False,
+    default=False,
+    help="Skip consistency check.",
+)
 @click.pass_context
-def cli(ctx) -> None:
+def cli(click_context, skip_consistency_check: bool) -> None:
     """Command-line tool for setting up an Autonomous Economic Agent."""
-    ctx.obj = Context(cwd=".")
+    verbosity_option = click_context.meta.pop("verbosity")
+    click_context.obj = Context(cwd=".", verbosity=verbosity_option)
+    click_context.obj.set_config("skip_consistency_check", skip_consistency_check)
 
 
 @cli.command()
 @click.argument(
     "agent_name", type=AgentDirectory(), required=True,
 )
-@pass_ctx
-def delete(ctx: Context, agent_name):
+@click.pass_context
+def delete(click_context, agent_name):
     """Delete an agent."""
     click.echo("Deleting AEA project directory './{}'...".format(agent_name))
 
@@ -99,10 +113,11 @@ def delete(ctx: Context, agent_name):
 
 
 @cli.command()
-@pass_ctx
-def freeze(ctx: Context):
+@click.pass_context
+@check_aea_project
+def freeze(click_context):
     """Get the dependencies."""
-    try_to_load_agent_config(ctx)
+    ctx = cast(Context, click_context.obj)
     for dependency_name, dependency_data in sorted(
         ctx.get_dependencies().items(), key=lambda x: x[0]
     ):
@@ -110,9 +125,9 @@ def freeze(ctx: Context):
 
 
 @cli.command()
-@pass_ctx
 @click.option("-p", "--port", default=8080)
-def gui(ctx: Context, port):
+@click.pass_context
+def gui(click_context, port):
     """Run the CLI GUI."""
     import aea.cli_gui  # pragma: no cover
 
@@ -127,8 +142,8 @@ def gui(ctx: Context, port):
     type=click.Choice([FetchAICrypto.identifier, EthereumCrypto.identifier, "all"]),
     required=True,
 )
-@pass_ctx
-def generate_key(ctx: Context, type_):
+@click.pass_context
+def generate_key(click_context, type_):
     """Generate private keys."""
 
     def _can_write(path) -> bool:
@@ -173,10 +188,11 @@ def _try_add_key(ctx, type_, filepath):
     type=click.Path(exists=True, file_okay=True, dir_okay=False, readable=True),
     required=True,
 )
-@pass_ctx
-def add_key(ctx: Context, type_, file):
+@click.pass_context
+@check_aea_project
+def add_key(click_context, type_, file):
     """Add a private key to the wallet."""
-    try_to_load_agent_config(ctx)
+    ctx = cast(Context, click_context.obj)
     _validate_private_key_path(file, type_)
     _try_add_key(ctx, type_, file)
 
@@ -202,10 +218,11 @@ def _try_get_address(ctx, type_):
     type=click.Choice([FetchAICrypto.identifier, EthereumCrypto.identifier]),
     required=True,
 )
-@pass_ctx
-def get_address(ctx: Context, type_):
+@click.pass_context
+@check_aea_project
+def get_address(click_context, type_):
     """Get the address associated with the private key."""
-    try_to_load_agent_config(ctx)
+    ctx = cast(Context, click_context.obj)
     _verify_or_create_private_keys(ctx)
     address = _try_get_address(ctx, type_)
     click.echo(address)
@@ -240,10 +257,10 @@ def _try_get_wealth(ctx, type_):
     type=click.Choice([FetchAICrypto.identifier, EthereumCrypto.identifier]),
     required=True,
 )
-@pass_ctx
+@click.pass_context
+@check_aea_project
 def get_wealth(ctx: Context, type_):
     """Get the wealth associated with the private key."""
-    try_to_load_agent_config(ctx)
     _verify_or_create_private_keys(ctx)
     wealth = _try_get_wealth(ctx, type_)
     click.echo(wealth)
@@ -292,10 +309,11 @@ def _try_generate_wealth(ctx, type_, sync):
 @click.option(
     "--sync", is_flag=True, help="For waiting till the faucet has released the funds."
 )
-@pass_ctx
-def generate_wealth(ctx: Context, sync, type_):
+@click.pass_context
+@check_aea_project
+def generate_wealth(click_context, sync, type_):
     """Generate wealth for address on test network."""
-    try_to_load_agent_config(ctx)
+    ctx = cast(Context, click_context.obj)
     _verify_or_create_private_keys(ctx)
     _try_generate_wealth(ctx, type_, sync)
 
@@ -305,13 +323,16 @@ cli.add_command(add)
 cli.add_command(create)
 cli.add_command(config)
 cli.add_command(fetch)
+cli.add_command(fingerprint)
 cli.add_command(generate)
 cli.add_command(init)
 cli.add_command(install)
 cli.add_command(launch)
 cli.add_command(login)
+cli.add_command(logout)
 cli.add_command(publish)
 cli.add_command(push)
+cli.add_command(register)
 cli.add_command(remove)
 cli.add_command(run)
 cli.add_command(scaffold)
