@@ -23,12 +23,13 @@ from shutil import rmtree
 
 import click
 
-from aea.cli.common import Context
-from aea.cli.registry.utils import download_file, extract, fetch_package, request_api
+from aea.cli.add import _add_item
+from aea.cli.common import Context, try_to_load_agent_config
+from aea.cli.registry.utils import download_file, extract, request_api
 from aea.configurations.base import PublicId
 
 
-def fetch_agent(ctx: Context, public_id: PublicId) -> None:
+def fetch_agent(ctx: Context, public_id: PublicId, click_context) -> None:
     """
     Fetch Agent from Registry.
 
@@ -41,16 +42,25 @@ def fetch_agent(ctx: Context, public_id: PublicId) -> None:
     resp = request_api("GET", api_path)
     file_url = resp["file"]
 
+    filepath = download_file(file_url, ctx.cwd)
+    extract(filepath, ctx.cwd)
+
     target_folder = os.path.join(ctx.cwd, name)
-    os.makedirs(target_folder, exist_ok=True)
+    ctx.cwd = target_folder
+    try_to_load_agent_config(ctx)
 
     click.echo("Fetching dependencies...")
-    for item_type in ("connection", "skill", "protocol"):
+    for item_type in ("connection", "contract", "skill", "protocol"):
         item_type_plural = item_type + "s"
-        for item_public_id in resp[item_type_plural]:
-            item_public_id = PublicId.from_str(item_public_id)
+
+        # initialize fetched agent with empty folders for custom packages
+        custom_items_folder = os.path.join(ctx.cwd, item_type_plural)
+        os.makedirs(custom_items_folder)
+
+        config = getattr(ctx.agent_config, item_type_plural)
+        for item_public_id in config:
             try:
-                fetch_package(item_type, item_public_id, target_folder)
+                _add_item(click_context, item_type, item_public_id)
             except Exception as e:
                 rmtree(target_folder)
                 raise click.ClickException(
@@ -59,7 +69,4 @@ def fetch_agent(ctx: Context, public_id: PublicId) -> None:
                     )
                 )
     click.echo("Dependencies successfully fetched.")
-
-    filepath = download_file(file_url, ctx.cwd)
-    extract(filepath, target_folder)
     click.echo("Agent {} successfully fetched to {}.".format(name, target_folder))
