@@ -31,7 +31,6 @@ from aea.cli.common import (
     Context,
     DEFAULT_REGISTRY_PATH,
     _format_items,
-    _format_skills,
     _retrieve_details,
     logger,
     pass_ctx,
@@ -41,15 +40,16 @@ from aea.cli.registry.utils import request_api
 from aea.configurations.base import (
     DEFAULT_AEA_CONFIG_FILE,
     DEFAULT_CONNECTION_CONFIG_FILE,
+    DEFAULT_CONTRACT_CONFIG_FILE,
     DEFAULT_PROTOCOL_CONFIG_FILE,
     DEFAULT_SKILL_CONFIG_FILE,
 )
 
 
 @click.group()
-@click.option("--registry", is_flag=True, help="For Registry search.")
-@pass_ctx
-def search(ctx: Context, registry):
+@click.option("--local", is_flag=True, help="For local search.")
+@click.pass_context
+def search(click_context, local):
     """Search for components in the registry.
 
     If called from an agent directory, it will check
@@ -57,11 +57,11 @@ def search(ctx: Context, registry):
     E.g.
 
         aea search connections
-        aea search --registry skills
+        aea search --local skills
     """
-    if registry:
-        ctx.set_config("is_registry", True)
-    else:
+    ctx = cast(Context, click_context.obj)
+    if local:
+        ctx.set_config("is_local", True)
         # if we are in an agent directory, try to load the configuration file.
         # otherwise, use the default path (i.e. 'packages/' in the current directory.)
         try:
@@ -103,40 +103,85 @@ def _get_details_from_dir(
         results.append(details)
 
 
+def _search_items(ctx, item_type_plural):
+    registry = cast(str, ctx.config.get("registry_directory"))
+    result = []  # type: List[Dict]
+    configs = {
+        "agents": {"loader": ctx.agent_loader, "config_file": DEFAULT_AEA_CONFIG_FILE},
+        "connections": {
+            "loader": ctx.connection_loader,
+            "config_file": DEFAULT_CONNECTION_CONFIG_FILE,
+        },
+        "contracts": {
+            "loader": ctx.contract_loader,
+            "config_file": DEFAULT_CONTRACT_CONFIG_FILE,
+        },
+        "protocols": {
+            "loader": ctx.protocol_loader,
+            "config_file": DEFAULT_PROTOCOL_CONFIG_FILE,
+        },
+        "skills": {
+            "loader": ctx.skill_loader,
+            "config_file": DEFAULT_SKILL_CONFIG_FILE,
+        },
+    }
+    if item_type_plural == "agents":
+        lookup_dir = registry
+    else:
+        lookup_dir = AEA_DIR
+        _get_details_from_dir(
+            configs[item_type_plural]["loader"],
+            registry,
+            "*/{}".format(item_type_plural),
+            configs[item_type_plural]["config_file"],
+            result,
+        )
+
+    _get_details_from_dir(
+        configs[item_type_plural]["loader"],
+        lookup_dir,
+        item_type_plural,
+        configs[item_type_plural]["config_file"],
+        result,
+    )
+
+    return sorted(result, key=lambda k: k["name"])
+
+
 @search.command()
 @click.option("--query", default="", help="Query string to search Connections by name.")
 @pass_ctx
 def connections(ctx: Context, query):
     """Search for Connections."""
-    if ctx.config.get("is_registry"):
-        click.echo('Searching for "{}"...'.format(query))
-        resp = request_api("GET", "/connections", params={"search": query})
-        if len(resp) == 0:
-            click.echo("No connections found.")  # pragma: no cover
-        else:
-            click.echo("Connections found:\n")
-            click.echo(_format_items(resp))
-        return
+    click.echo('Searching for "{}"...'.format(query))
+    if ctx.config.get("is_local"):
+        results = _search_items(ctx, "connections")
+    else:
+        results = request_api("GET", "/connections", params={"search": query})
 
-    registry = cast(str, ctx.config.get("registry_directory"))
-    result = []  # type: List[Dict]
-    _get_details_from_dir(
-        ctx.connection_loader,
-        AEA_DIR,
-        "connections",
-        DEFAULT_CONNECTION_CONFIG_FILE,
-        result,
-    )
-    _get_details_from_dir(
-        ctx.connection_loader,
-        registry,
-        "*/connections",
-        DEFAULT_CONNECTION_CONFIG_FILE,
-        result,
-    )
+    if not len(results):
+        click.echo("No connections found.")  # pragma: no cover
+    else:
+        click.echo("Connections found:\n")
+        click.echo(_format_items(results))
 
-    print("Available connections:")
-    print(_format_items(sorted(result, key=lambda k: k["name"])))
+
+@search.command()
+@click.option("--query", default="", help="Query string to search Contracts by name.")
+@pass_ctx
+def contracts(ctx: Context, query):
+    """Search for Contracts."""
+    click.echo('Searching for "{}"...'.format(query))
+    if ctx.config.get("is_local"):
+        results = _search_items(ctx, "contracts")
+    else:
+        results = request_api("GET", "/contracts", params={"search": query})
+
+    if not len(results):
+        click.echo("No contracts found.")  # pragma: no cover
+    else:
+        click.echo("Contracts found:\n")
+        click.echo(_format_items(results))
 
 
 @search.command()
@@ -144,31 +189,17 @@ def connections(ctx: Context, query):
 @pass_ctx
 def protocols(ctx: Context, query):
     """Search for Protocols."""
-    if ctx.config.get("is_registry"):
-        click.echo('Searching for "{}"...'.format(query))
-        resp = request_api("GET", "/protocols", params={"search": query})
-        if len(resp) == 0:
-            click.echo("No protocols found.")  # pragma: no cover
-        else:
-            click.echo("Protocols found:\n")
-            click.echo(_format_items(resp))
-        return
+    click.echo('Searching for "{}"...'.format(query))
+    if ctx.config.get("is_local"):
+        results = _search_items(ctx, "protocols")
+    else:
+        results = request_api("GET", "/protocols", params={"search": query})
 
-    registry = cast(str, ctx.config.get("registry_directory"))
-    result = []  # type: List[Dict]
-    _get_details_from_dir(
-        ctx.protocol_loader, AEA_DIR, "protocols", DEFAULT_PROTOCOL_CONFIG_FILE, result
-    )
-    _get_details_from_dir(
-        ctx.protocol_loader,
-        registry,
-        "*/protocols",
-        DEFAULT_PROTOCOL_CONFIG_FILE,
-        result,
-    )
-
-    print("Available protocols:")
-    print(_format_items(sorted(result, key=lambda k: k["name"])))
+    if not len(results):
+        click.echo("No protocols found.")  # pragma: no cover
+    else:
+        click.echo("Protocols found:\n")
+        click.echo(_format_items(results))
 
 
 @search.command()
@@ -176,27 +207,17 @@ def protocols(ctx: Context, query):
 @pass_ctx
 def skills(ctx: Context, query):
     """Search for Skills."""
-    if ctx.config.get("is_registry"):
-        click.echo('Searching for "{}"...'.format(query))
-        resp = request_api("GET", "/skills", params={"search": query})
-        if len(resp) == 0:
-            click.echo("No skills found.")  # pragma: no cover
-        else:
-            click.echo("Skills found:\n")
-            click.echo(_format_skills(resp))
-        return
+    click.echo('Searching for "{}"...'.format(query))
+    if ctx.config.get("is_local"):
+        results = _search_items(ctx, "skills")
+    else:
+        results = request_api("GET", "/skills", params={"search": query})
 
-    registry = cast(str, ctx.config.get("registry_directory"))
-    result: List[Dict] = []
-    _get_details_from_dir(
-        ctx.skill_loader, AEA_DIR, "skills", DEFAULT_SKILL_CONFIG_FILE, result
-    )
-    _get_details_from_dir(
-        ctx.skill_loader, registry, "*/skills", DEFAULT_SKILL_CONFIG_FILE, result
-    )
-
-    print("Available skills:")
-    print(_format_items(sorted(result, key=lambda k: k["name"])))
+    if not len(results):
+        click.echo("No skills found.")  # pragma: no cover
+    else:
+        click.echo("Skills found:\n")
+        click.echo(_format_items(results))
 
 
 @search.command()
@@ -204,20 +225,14 @@ def skills(ctx: Context, query):
 @pass_ctx
 def agents(ctx: Context, query):
     """Search for Agents."""
-    if ctx.config.get("is_registry"):
-        resp = request_api("GET", "/agents", params={"search": query})
-        if len(resp) == 0:
-            click.echo("No agents found.")  # pragma: no cover
-        else:
-            click.echo("Agents found:\n")
-            click.echo(_format_items(resp))
-        return
+    click.echo('Searching for "{}"...'.format(query))
+    if ctx.config.get("is_local"):
+        results = _search_items(ctx, "agents")
     else:
-        registry = cast(str, ctx.config.get("registry_directory"))
-        result = []  # type: List[Dict]
-        _get_details_from_dir(
-            ctx.agent_loader, registry, "agents", DEFAULT_AEA_CONFIG_FILE, result
-        )
+        results = request_api("GET", "/agents", params={"search": query})
 
-        print("Available agents:")
-        print(_format_items(sorted(result, key=lambda k: k["name"])))
+    if not len(results):
+        click.echo("No agents found.")  # pragma: no cover
+    else:
+        click.echo("Agents found:\n")
+        click.echo(_format_items(results))
