@@ -24,7 +24,7 @@ import json
 import os
 import re
 from pathlib import Path
-from typing import Generic, TextIO, Type, TypeVar, Union
+from typing import Dict, Generic, TextIO, Type, TypeVar, Union
 
 import jsonschema
 from jsonschema import Draft4Validator
@@ -36,10 +36,12 @@ from aea.configurations.base import (
     AgentConfig,
     ConfigurationType,
     ConnectionConfig,
+    ContractConfig,
     ProtocolConfig,
     ProtocolSpecification,
     SkillConfig,
 )
+from aea.helpers.base import yaml_dump, yaml_load
 
 _CUR_DIR = os.path.dirname(inspect.getfile(inspect.currentframe()))  # type: ignore
 _SCHEMAS_DIR = os.path.join(_CUR_DIR, "schemas")
@@ -49,6 +51,7 @@ T = TypeVar(
     AgentConfig,
     SkillConfig,
     ConnectionConfig,
+    ContractConfig,
     ProtocolConfig,
     ProtocolSpecification,
 )
@@ -57,18 +60,28 @@ T = TypeVar(
 class ConfigLoader(Generic[T]):
     """This class implement parsing, serialization and validation functionalities for the 'aea' configuration files."""
 
-    def __init__(self, schema_filename: str, configuration_type: Type[T]):
+    def __init__(self, schema_filename: str, configuration_class: Type[T]):
         """
         Initialize the parser for configuration files.
 
         :param schema_filename: the path to the JSON-schema file in 'aea/configurations/schemas'.
-        :param configuration_type:
+        :param configuration_class: the configuration class (e.g. AgentConfig, SkillConfig etc.)
         """
-        self.schema = json.load(open(os.path.join(_SCHEMAS_DIR, schema_filename)))
+        self._schema = json.load(open(os.path.join(_SCHEMAS_DIR, schema_filename)))
         root_path = "file://{}{}".format(Path(_SCHEMAS_DIR).absolute(), os.path.sep)
-        self.resolver = jsonschema.RefResolver(root_path, self.schema)
-        self.validator = Draft4Validator(self.schema, resolver=self.resolver)
-        self.configuration_type = configuration_type  # type: Type[T]
+        self._resolver = jsonschema.RefResolver(root_path, self._schema)
+        self._validator = Draft4Validator(self._schema, resolver=self._resolver)
+        self._configuration_class = configuration_class  # type: Type[T]
+
+    @property
+    def validator(self) -> Draft4Validator:
+        """Get the json schema validator."""
+        return self._validator
+
+    @property
+    def configuration_class(self) -> Type[T]:
+        """Get the configuration type of the loader."""
+        return self._configuration_class
 
     def load_protocol_specification(self, file_pointer: TextIO) -> T:
         """
@@ -93,7 +106,7 @@ class ConfigLoader(Generic[T]):
             self.validator.validate(instance=configuration_file_json)
         except Exception:
             raise
-        protocol_specification = self.configuration_type.from_json(
+        protocol_specification = self.configuration_class.from_json(
             configuration_file_json
         )
         protocol_specification.protobuf_snippets = protobuf_snippets_json
@@ -107,12 +120,15 @@ class ConfigLoader(Generic[T]):
         :return: the configuration object.
         :raises
         """
-        configuration_file_json = yaml.safe_load(file_pointer)
+        configuration_file_json = yaml_load(file_pointer)
         try:
             self.validator.validate(instance=configuration_file_json)
         except Exception:
             raise
-        return self.configuration_type.from_json(configuration_file_json)
+        key_order = list(configuration_file_json.keys())
+        configuration_obj = self.configuration_class.from_json(configuration_file_json)
+        configuration_obj._key_order = key_order
+        return configuration_obj
 
     def dump(self, configuration: T, file_pointer: TextIO) -> None:
         """Dump a configuration.
@@ -121,9 +137,9 @@ class ConfigLoader(Generic[T]):
         :param file_pointer: the file pointer to the configuration file
         :return: None
         """
-        result = configuration.json
+        result = configuration.ordered_json
         self.validator.validate(instance=result)
-        yaml.safe_dump(result, file_pointer)
+        yaml_dump(result, file_pointer)
 
     @classmethod
     def from_configuration_type(
@@ -131,16 +147,31 @@ class ConfigLoader(Generic[T]):
     ) -> "ConfigLoader":
         """Get the configuration loader from the type."""
         configuration_type = ConfigurationType(configuration_type)
-        if configuration_type == ConfigurationType.AGENT:
-            return ConfigLoader("aea-config_schema.json", AgentConfig)
-        elif configuration_type == ConfigurationType.PROTOCOL:
-            return ConfigLoader("protocol-config_schema.json", ProtocolConfig)
-        elif configuration_type == ConfigurationType.CONNECTION:
-            return ConfigLoader("connection-config_schema.json", ConnectionConfig)
-        elif configuration_type == ConfigurationType.SKILL:
-            return ConfigLoader("skill-config_schema.json", SkillConfig)
-        else:  # pragma: no cover
-            raise ValueError("Invalid configuration type.")
+        return ConfigLoaders.from_configuration_type(configuration_type)
+
+
+class ConfigLoaders:
+
+    _from_configuration_type_to_loaders = {
+        ConfigurationType.AGENT: ConfigLoader("aea-config_schema.json", AgentConfig),
+        ConfigurationType.PROTOCOL: ConfigLoader(
+            "protocol-config_schema.json", ProtocolConfig
+        ),
+        ConfigurationType.CONNECTION: ConfigLoader(
+            "connection-config_schema.json", ConnectionConfig
+        ),
+        ConfigurationType.SKILL: ConfigLoader("skill-config_schema.json", SkillConfig),
+        ConfigurationType.CONTRACT: ConfigLoader(
+            "contract-config_schema.json", ContractConfig
+        ),
+    }  # type: Dict[ConfigurationType, ConfigLoader]
+
+    @classmethod
+    def from_configuration_type(
+        cls, configuration_type: Union[ConfigurationType, str]
+    ) -> "ConfigLoader":
+        configuration_type = ConfigurationType(configuration_type)
+        return cls._from_configuration_type_to_loaders[configuration_type]
 
 
 def _config_loader():
