@@ -112,7 +112,6 @@ class StubConnection(Connection):
         self,
         input_file_path: Union[str, Path],
         output_file_path: Union[str, Path],
-        *args,
         **kwargs
     ):
         """
@@ -120,14 +119,10 @@ class StubConnection(Connection):
 
         :param input_file_path: the input file for the incoming messages.
         :param output_file_path: the output file for the outgoing messages.
-        :param connection_id: the identifier of the connection object.
-        :param restricted_to_protocols: the only supported protocols for this connection.
-        :param excluded_protocols: the set of protocols ids that we want to exclude for this connection.
         """
-        if kwargs.get("connection_id") is None:
+        if kwargs.get("configuration") is None and kwargs.get("connection_id") is None:
             kwargs["connection_id"] = PublicId("fetchai", "stub", "0.1.0")
-        super().__init__(*args, **kwargs)
-
+        super().__init__(**kwargs)
         input_file_path = Path(input_file_path)
         output_file_path = Path(output_file_path)
         if not input_file_path.exists():
@@ -231,31 +226,27 @@ class StubConnection(Connection):
 
     @classmethod
     def from_config(
-        cls, address: Address, connection_configuration: ConnectionConfig
+        cls, address: Address, configuration: ConnectionConfig
     ) -> "Connection":
         """
-        Get the OEF connection from the connection configuration.
+        Get the stub connection from the connection configuration.
 
         :param address: the address of the agent.
-        :param connection_configuration: the connection configuration object.
+        :param configuration: the connection configuration object.
         :return: the connection object
         """
-        input_file = connection_configuration.config.get(
-            "input_file", "./input_file"
-        )  # type: str
-        output_file = connection_configuration.config.get(
+        input_file = configuration.config.get("input_file", "./input_file")  # type: str
+        output_file = configuration.config.get(
             "output_file", "./output_file"
         )  # type: str
         restricted_to_protocols_names = {
-            p.name for p in connection_configuration.restricted_to_protocols
-        }
-        excluded_protocols_names = {
-            p.name for p in connection_configuration.excluded_protocols
+            p.name for p in configuration.restricted_to_protocols
         }
+        excluded_protocols_names = {p.name for p in configuration.excluded_protocols}
         return StubConnection(
             input_file,
             output_file,
-            connection_id=connection_configuration.public_id,
+            connection_id=configuration.public_id,
             restricted_to_protocols=restricted_to_protocols_names,
             excluded_protocols=excluded_protocols_names,
         )
