@@ -77,7 +77,7 @@ from packages.fetchai.protocols.fipa.serialization import FipaSerializer
 from packages.fetchai.protocols.oef_search.message import OefSearchMessage
 from packages.fetchai.protocols.oef_search.serialization import OefSearchSerializer
 
-logger = logging.getLogger(__name__)
+logger = logging.getLogger("aea.packages.fetchai.connections.oef")
 
 TARGET = 0
 MESSAGE_ID = 1
@@ -606,28 +606,22 @@ class OEFChannel(OEFAgent):
 class OEFConnection(Connection):
     """The OEFConnection connects the to the mailbox."""
 
-    def __init__(
-        self, address: Address, oef_addr: str, oef_port: int = 10000, *args, **kwargs
-    ):
+    def __init__(self, oef_addr: str, oef_port: int = 10000, **kwargs):
         """
         Initialize.
 
-        :param address: the address of the agent.
         :param oef_addr: the OEF IP address.
         :param oef_port: the OEF port.
-        :param connection_id: the identifier of the connection object.
-        :param restricted_to_protocols: the only supported protocols for this connection.
-        :param excluded_protocols: the excluded protocols for this connection.
+        :param kwargs: the keyword arguments (check the parent constructor)
         """
-        if kwargs.get("connection_id") is None:
+        if kwargs.get("configuration") is None and kwargs.get("connection_id") is None:
             kwargs["connection_id"] = PublicId("fetchai", "oef", "0.1.0")
-        super().__init__(*args, **kwargs)
+        super().__init__(**kwargs)
+        self.oef_addr = oef_addr
+        self.oef_port = oef_port
         self._core = AsyncioCore(logger=logger)  # type: AsyncioCore
         self.in_queue = None  # type: Optional[asyncio.Queue]
-        self.channel = OEFChannel(
-            address, oef_addr, oef_port, core=self._core,
-        )  # type: ignore
-
+        self.channel = OEFChannel(self.address, self.oef_addr, self.oef_port, core=self._core)  # type: ignore
         self._connection_check_task = None  # type: Optional[asyncio.Future]
 
     async def connect(self) -> None:
@@ -743,28 +737,16 @@ class OEFConnection(Connection):
 
     @classmethod
     def from_config(
-        cls, address: Address, connection_configuration: ConnectionConfig
+        cls, address: Address, configuration: ConnectionConfig
     ) -> "Connection":
         """
         Get the OEF connection from the connection configuration.
-
         :param address: the address of the agent.
-        :param connection_configuration: the connection configuration object.
+        :param configuration: the connection configuration object.
         :return: the connection object
         """
-        oef_addr = cast(str, connection_configuration.config.get("addr"))
-        oef_port = cast(int, connection_configuration.config.get("port"))
-        restricted_to_protocols_names = {
-            p.name for p in connection_configuration.restricted_to_protocols
-        }
-        excluded_protocols_names = {
-            p.name for p in connection_configuration.excluded_protocols
-        }
+        oef_addr = cast(str, configuration.config.get("addr"))
+        oef_port = cast(int, configuration.config.get("port"))
         return OEFConnection(
-            address,
-            oef_addr,
-            oef_port,
-            connection_id=connection_configuration.public_id,
-            restricted_to_protocols=restricted_to_protocols_names,
-            excluded_protocols=excluded_protocols_names,
+            oef_addr, oef_port, address=address, configuration=configuration
         )
