@@ -26,7 +26,9 @@ import time
 
 import skimage  # type: ignore
 
-logger = logging.getLogger("aea.carpark_detection_skill")
+logger = logging.getLogger(
+    "aea.packages.fetchai.skills.carpark_detection.detection_database"
+)
 
 
 class DetectionDatabase:
@@ -301,7 +303,7 @@ class DetectionDatabase:
         self.execute_single_sql(command, variables)
 
     def lookup_friendly_name(self, oef_key):
-        """Look iup friendly name given the OEF key."""
+        """Look up friendly name given the OEF key."""
         command = "SELECT * FROM name_lookup2 WHERE oef_key = ? ORDER BY epoch DESC"
         variables = (str(oef_key),)
         results = self.execute_single_sql(command, variables)
