@@ -78,7 +78,7 @@ class Strategy(Model):
 
     @property
     def is_registering_as_seller(self) -> bool:
-        """Check if the agent registers as a seller on the OEF."""
+        """Check if the agent registers as a seller on the OEF service directory."""
         return (
             self._register_as == Strategy.RegisterAs.SELLER
             or self._register_as == Strategy.RegisterAs.BUYER
@@ -86,7 +86,7 @@ class Strategy(Model):
 
     @property
     def is_searching_for_sellers(self) -> bool:
-        """Check if the agent searches for sellers on the OEF."""
+        """Check if the agent searches for sellers on the OEF service directory."""
         return (
             self._search_for == Strategy.SearchFor.SELLERS
             or self._search_for == Strategy.SearchFor.BOTH
@@ -94,7 +94,7 @@ class Strategy(Model):
 
     @property
     def is_registering_as_buyer(self) -> bool:
-        """Check if the agent registers as a buyer on the OEF."""
+        """Check if the agent registers as a buyer on the OEF service directory."""
         return (
             self._register_as == Strategy.RegisterAs.BUYER
             or self._register_as == Strategy.RegisterAs.BOTH
@@ -102,7 +102,7 @@ class Strategy(Model):
 
     @property
     def is_searching_for_buyers(self) -> bool:
-        """Check if the agent searches for buyers on the OEF."""
+        """Check if the agent searches for buyers on the OEF service directory."""
         return (
             self._search_for == Strategy.SearchFor.BUYERS
             or self._search_for == Strategy.SearchFor.BOTH
@@ -329,7 +329,7 @@ class Strategy(Model):
         )
         if not ownership_state_after_locks.is_affordable_transaction(transaction_msg):
             return False
-        proposal_delta_score = self.context.agent_preferences.get_score_diff_from_transaction(
+        proposal_delta_score = self.context.agent_preferences.utility_diff_from_transaction(
             ownership_state_after_locks, transaction_msg
         )
         if proposal_delta_score >= 0:
