@@ -115,8 +115,8 @@ class FIPAHandler(Handler):
             performative=DefaultMessage.Performative.ERROR,
             error_code=DefaultMessage.ErrorCode.INVALID_DIALOGUE,
             error_msg="Invalid dialogue.",
-            error_data="fipa_message",
-        )  # TODO: send FipaSerializer().encode(msg)
+            error_data={"fipa_message": b""},
+        )
         self.context.outbox.put_message(
             to=msg.counterparty,
             sender=self.context.agent_address,
