@@ -51,11 +51,17 @@ class TestLaunch:
         cls.cwd = os.getcwd()
         cls.t = tempfile.mkdtemp()
         os.chdir(cls.t)
-        result = cls.runner.invoke(cli, [*CLI_LOG_OPTION, "init", "--author", AUTHOR])
+        result = cls.runner.invoke(
+            cli, [*CLI_LOG_OPTION, "init", "--local", "--author", AUTHOR]
+        )
         assert result.exit_code == 0
-        result = cls.runner.invoke(cli, [*CLI_LOG_OPTION, "create", cls.agent_name_1])
+        result = cls.runner.invoke(
+            cli, [*CLI_LOG_OPTION, "create", "--local", cls.agent_name_1]
+        )
         assert result.exit_code == 0
-        result = cls.runner.invoke(cli, [*CLI_LOG_OPTION, "create", cls.agent_name_2])
+        result = cls.runner.invoke(
+            cli, [*CLI_LOG_OPTION, "create", "--local", cls.agent_name_2]
+        )
         assert result.exit_code == 0
 
     def test_exit_code_equal_to_zero(self, pytestconfig):
@@ -77,11 +83,11 @@ class TestLaunch:
                 preexec_fn=os.setsid,
             )
 
-            time.sleep(5.0)
+            time.sleep(10.0)
             os.killpg(
                 os.getpgid(process_launch.pid), signal.SIGINT
             )  # Send the signal to all the process groups
-            process_launch.wait(timeout=5.0)
+            process_launch.wait(timeout=10.0)
         finally:
             if not process_launch.returncode == 0:
                 poll_one = process_launch.poll()
@@ -114,11 +120,17 @@ class TestLaunchWithOneFailingAgent:
         cls.t = tempfile.mkdtemp()
         os.chdir(cls.t)
 
-        result = cls.runner.invoke(cli, [*CLI_LOG_OPTION, "init", "--author", AUTHOR])
+        result = cls.runner.invoke(
+            cli, [*CLI_LOG_OPTION, "init", "--local", "--author", AUTHOR]
+        )
         assert result.exit_code == 0
-        result = cls.runner.invoke(cli, [*CLI_LOG_OPTION, "create", cls.agent_name_1])
+        result = cls.runner.invoke(
+            cli, [*CLI_LOG_OPTION, "create", "--local", cls.agent_name_1]
+        )
         assert result.exit_code == 0
-        result = cls.runner.invoke(cli, [*CLI_LOG_OPTION, "create", cls.agent_name_2])
+        result = cls.runner.invoke(
+            cli, [*CLI_LOG_OPTION, "create", "--local", cls.agent_name_2]
+        )
         assert result.exit_code == 0
 
         # add the exception skill to agent 2
