@@ -44,7 +44,7 @@ from ..conftest import (
 )
 
 
-class TestSearchProtocols:
+class TestSearchProtocolsLocal:
     """Test that the command 'aea search protocols' works as expected."""
 
     @classmethod
@@ -58,10 +58,14 @@ class TestSearchProtocols:
         """Test that the command has printed the correct output when using the default registry."""
         os.chdir(AEA_DIR)
         self.result = self.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "search", "protocols"], standalone_mode=False
+            cli,
+            [*CLI_LOG_OPTION, "search", "--local", "protocols"],
+            standalone_mode=False,
         )
-        assert self.result.output == "Available protocols:\n{}\n".format(
-            FORMAT_ITEMS_SAMPLE_OUTPUT
+        assert self.result.output == (
+            'Searching for ""...\n'
+            "Protocols found:\n\n"
+            "{}\n".format(FORMAT_ITEMS_SAMPLE_OUTPUT)
         )
 
     @classmethod
@@ -70,7 +74,43 @@ class TestSearchProtocols:
         os.chdir(cls.cwd)
 
 
-class TestSearchConnections:
+class TestSearchContractsLocal(TestCase):
+    """Test that the command 'aea search contracts' works as expected."""
+
+    def setUp(self):
+        """Set the test up."""
+        self.runner = CliRunner()
+
+    @mock.patch("aea.cli.search._format_items", return_value=FORMAT_ITEMS_SAMPLE_OUTPUT)
+    @mock.patch("aea.cli.search._search_items", return_value=["item1"])
+    def test_search_contracts_positive(self, *mocks):
+        """Test search contracts command positive result."""
+        result = self.runner.invoke(
+            cli,
+            [*CLI_LOG_OPTION, "search", "--local", "contracts"],
+            standalone_mode=False,
+        )
+        assert result.output == (
+            'Searching for ""...\n'
+            "Contracts found:\n\n"
+            "{}\n".format(FORMAT_ITEMS_SAMPLE_OUTPUT)
+        )
+
+    @mock.patch("aea.cli.search._format_items", return_value=FORMAT_ITEMS_SAMPLE_OUTPUT)
+    @mock.patch("aea.cli.search.request_api", return_value=["item1"])
+    def test_search_contracts_registry_positive(self, *mocks):
+        """Test search contracts in registry command positive result."""
+        result = self.runner.invoke(
+            cli, [*CLI_LOG_OPTION, "search", "contracts"], standalone_mode=False,
+        )
+        assert result.output == (
+            'Searching for ""...\n'
+            "Contracts found:\n\n"
+            "{}\n".format(FORMAT_ITEMS_SAMPLE_OUTPUT)
+        )
+
+
+class TestSearchConnectionsLocal:
     """Test that the command 'aea search connections' works as expected."""
 
     @classmethod
@@ -84,10 +124,14 @@ class TestSearchConnections:
         """Test that the command has printed the correct output when using the default registry."""
         os.chdir(AEA_DIR)
         self.result = self.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "search", "connections"], standalone_mode=False
+            cli,
+            [*CLI_LOG_OPTION, "search", "--local", "connections"],
+            standalone_mode=False,
         )
-        assert self.result.output == "Available connections:\n{}\n".format(
-            FORMAT_ITEMS_SAMPLE_OUTPUT
+        assert self.result.output == (
+            'Searching for ""...\n'
+            "Connections found:\n\n"
+            "{}\n".format(FORMAT_ITEMS_SAMPLE_OUTPUT)
         )
 
     @classmethod
@@ -96,7 +140,7 @@ class TestSearchConnections:
         os.chdir(cls.cwd)
 
 
-class TestSearchSkills:
+class TestSearchSkillsLocal:
     """Test that the command 'aea search skills' works as expected."""
 
     @classmethod
@@ -110,10 +154,12 @@ class TestSearchSkills:
         """Test that the command has printed the correct output when using the default registry."""
         os.chdir(AEA_DIR)
         self.result = self.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "search", "skills"], standalone_mode=False
+            cli, [*CLI_LOG_OPTION, "search", "--local", "skills"], standalone_mode=False
         )
-        assert self.result.output == "Available skills:\n{}\n".format(
-            FORMAT_ITEMS_SAMPLE_OUTPUT
+        assert self.result.output == (
+            'Searching for ""...\n'
+            "Skills found:\n\n"
+            "{}\n".format(FORMAT_ITEMS_SAMPLE_OUTPUT)
         )
 
     @classmethod
@@ -122,7 +168,7 @@ class TestSearchSkills:
         os.chdir(cls.cwd)
 
 
-class TestSearchAgents:
+class TestSearchAgentsLocal:
     """Test that the command 'aea search agents' works as expected."""
 
     @classmethod
@@ -139,10 +185,14 @@ class TestSearchAgents:
 
         cls.t = tempfile.mkdtemp()
         os.chdir(cls.t)
-        result = cls.runner.invoke(cli, [*CLI_LOG_OPTION, "init", "--author", AUTHOR])
+        result = cls.runner.invoke(
+            cli, [*CLI_LOG_OPTION, "init", "--local", "--author", AUTHOR]
+        )
         assert result.exit_code == 0
         result = cls.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "create", "myagent"], standalone_mode=False
+            cli,
+            [*CLI_LOG_OPTION, "create", "--local", "myagent"],
+            standalone_mode=False,
         )
         assert result.exit_code == 0
 
@@ -152,13 +202,14 @@ class TestSearchAgents:
         )
         os.chdir(Path(cls.t, "myagent"))
         cls.result = cls.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "search", "agents"], standalone_mode=False
+            cli, [*CLI_LOG_OPTION, "search", "--local", "agents"], standalone_mode=False
         )
 
     def test_correct_output_default_registry(self):
         """Test that the command has printed the correct output when using the default registry."""
         assert (
-            self.result.output == "Available agents:\n"
+            self.result.output == 'Searching for ""...\n'
+            "Agents found:\n\n"
             "------------------------------\n"
             "Public ID: default_author/myagent:0.1.0\n"
             "Name: myagent\n"
@@ -191,7 +242,7 @@ class RegistrySearchTestCase(TestCase):
         """Test for CLI search --registry connections positive result."""
         result = self.runner.invoke(
             cli,
-            [*CLI_LOG_OPTION, "search", "--registry", "connections", "--query=some"],
+            [*CLI_LOG_OPTION, "search", "connections", "--query=some"],
             standalone_mode=False,
         )
         expected_output = (
@@ -209,10 +260,14 @@ class RegistrySearchTestCase(TestCase):
         """Test for CLI search --registry agents positive result."""
         result = self.runner.invoke(
             cli,
-            [*CLI_LOG_OPTION, "search", "--registry", "agents", "--query=some"],
+            [*CLI_LOG_OPTION, "search", "agents", "--query=some"],
             standalone_mode=False,
         )
-        expected_output = "Agents found:\n\n" "{}\n".format(FORMAT_ITEMS_SAMPLE_OUTPUT)
+        expected_output = (
+            'Searching for "some"...\n'
+            "Agents found:\n\n"
+            "{}\n".format(FORMAT_ITEMS_SAMPLE_OUTPUT)
+        )
         self.assertEqual(result.output, expected_output)
         request_api_mock.assert_called_once_with(
             "GET", "/agents", params={"search": "some"}
@@ -223,7 +278,7 @@ class RegistrySearchTestCase(TestCase):
         """Test for CLI search --registry protocols positive result."""
         result = self.runner.invoke(
             cli,
-            [*CLI_LOG_OPTION, "search", "--registry", "protocols", "--query=some"],
+            [*CLI_LOG_OPTION, "search", "protocols", "--query=some"],
             standalone_mode=False,
         )
         expected_output = (
@@ -237,16 +292,11 @@ class RegistrySearchTestCase(TestCase):
         )
         _format_items_mock.assert_called_once_with(["correct", "results"])
 
-    @mock.patch(
-        "aea.cli.search._format_skills", return_value=FORMAT_ITEMS_SAMPLE_OUTPUT
-    )
-    def test_search_skills_positive(
-        self, _format_skills_mock, _format_items_mock, request_api_mock
-    ):
+    def test_search_skills_positive(self, _format_items_mock, request_api_mock):
         """Test for CLI search --registry skills positive result."""
         result = self.runner.invoke(
             cli,
-            [*CLI_LOG_OPTION, "search", "--registry", "skills", "--query=some"],
+            [*CLI_LOG_OPTION, "search", "skills", "--query=some"],
             standalone_mode=False,
         )
         expected_output = (
@@ -258,11 +308,10 @@ class RegistrySearchTestCase(TestCase):
         request_api_mock.assert_called_once_with(
             "GET", "/skills", params={"search": "some"}
         )
-        _format_skills_mock.assert_called_once_with(["correct", "results"])
-        _format_items_mock.assert_not_called()
+        _format_items_mock.assert_called_once_with(["correct", "results"])
 
 
-class TestSearchWithRegistryInSubfolder:
+class TestSearchWithRegistryInSubfolderLocal:
     """Test the search when the registry directory is a subfolder of the current path."""
 
     @classmethod
@@ -282,7 +331,7 @@ class TestSearchWithRegistryInSubfolder:
                 shutil.rmtree(p)
 
         cls.result = cls.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "search", "skills"], standalone_mode=False
+            cli, [*CLI_LOG_OPTION, "search", "--local", "skills"], standalone_mode=False
         )
 
     def test_exit_code_equal_to_zero(self):
@@ -292,7 +341,8 @@ class TestSearchWithRegistryInSubfolder:
     def test_correct_output(self,):
         """Test that the command has printed the correct output.."""
         assert (
-            self.result.output == "Available skills:\n"
+            self.result.output == 'Searching for ""...\n'
+            "Skills found:\n\n"
             "------------------------------\n"
             "Public ID: fetchai/echo:0.1.0\n"
             "Name: echo\n"
@@ -319,7 +369,7 @@ class TestSearchWithRegistryInSubfolder:
             pass
 
 
-class TestSearchInAgentDirectory:
+class TestSearchInAgentDirectoryLocal:
     """Test the search when we are in the agent directory."""
 
     @classmethod
@@ -340,18 +390,22 @@ class TestSearchInAgentDirectory:
             if p.name != "echo" and p.is_dir()
         ]
 
-        result = cls.runner.invoke(cli, [*CLI_LOG_OPTION, "init", "--author", AUTHOR])
+        result = cls.runner.invoke(
+            cli, [*CLI_LOG_OPTION, "init", "--local", "--author", AUTHOR]
+        )
         assert result.exit_code == 0
 
         # create an AEA proejct and enter into it.
         result = cls.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "create", "myagent"], standalone_mode=False
+            cli,
+            [*CLI_LOG_OPTION, "create", "--local", "myagent"],
+            standalone_mode=False,
         )
         assert result.exit_code == 0
         os.chdir(Path(cls.t, "myagent"))
 
         cls.result = cls.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "search", "skills"], standalone_mode=False
+            cli, [*CLI_LOG_OPTION, "search", "--local", "skills"], standalone_mode=False
         )
 
     def test_exit_code_equal_to_zero(self):
@@ -361,7 +415,8 @@ class TestSearchInAgentDirectory:
     def test_correct_output(self,):
         """Test that the command has printed the correct output.."""
         assert (
-            self.result.output == "Available skills:\n"
+            self.result.output == 'Searching for ""...\n'
+            "Skills found:\n\n"
             "------------------------------\n"
             "Public ID: fetchai/echo:0.1.0\n"
             "Name: echo\n"
