@@ -42,10 +42,9 @@ def test_non_initialized_ownership_state_raises_exception():
 
 def test_initialisation():
     """Test the initialisation of the ownership_state."""
-    ownership_state = OwnershipState()
     currency_endowment = {"FET": 100}
     good_endowment = {"good_id": 2}
-    ownership_state.init(
+    ownership_state = OwnershipState(
         amount_by_currency_id=currency_endowment, quantities_by_good_id=good_endowment,
     )
     assert ownership_state.amount_by_currency_id is not None
@@ -74,10 +73,9 @@ def test_body():
 
 def test_transaction_is_affordable_agent_is_buyer():
     """Check if the agent has the money to cover the sender_amount (the agent=sender is the buyer)."""
-    ownership_state = OwnershipState()
     currency_endowment = {"FET": 100}
     good_endowment = {"good_id": 20}
-    ownership_state.init(
+    ownership_state = OwnershipState(
         amount_by_currency_id=currency_endowment, quantities_by_good_id=good_endowment,
     )
     tx_message = TransactionMessage(
@@ -102,10 +100,9 @@ def test_transaction_is_affordable_agent_is_buyer():
 
 def test_transaction_is_affordable_there_is_no_wealth():
     """Reject the transaction when there is no wealth exchange."""
-    ownership_state = OwnershipState()
     currency_endowment = {"FET": 0}
     good_endowment = {"good_id": 0}
-    ownership_state.init(
+    ownership_state = OwnershipState(
         amount_by_currency_id=currency_endowment, quantities_by_good_id=good_endowment,
     )
     tx_message = TransactionMessage(
@@ -130,10 +127,9 @@ def test_transaction_is_affordable_there_is_no_wealth():
 
 def tests_transaction_is_affordable_agent_is_the_seller():
     """Check if the agent has the goods (the agent=sender is the seller)."""
-    ownership_state = OwnershipState()
     currency_endowment = {"FET": 0}
     good_endowment = {"good_id": 0}
-    ownership_state.init(
+    ownership_state = OwnershipState(
         amount_by_currency_id=currency_endowment, quantities_by_good_id=good_endowment,
     )
     tx_message = TransactionMessage(
@@ -158,10 +154,9 @@ def tests_transaction_is_affordable_agent_is_the_seller():
 
 def tests_transaction_is_affordable_else_statement():
     """Check that the function returns false if we cannot satisfy any if/elif statements."""
-    ownership_state = OwnershipState()
     currency_endowment = {"FET": 0}
     good_endowment = {"good_id": 0}
-    ownership_state.init(
+    ownership_state = OwnershipState(
         amount_by_currency_id=currency_endowment, quantities_by_good_id=good_endowment,
     )
     tx_message = TransactionMessage(
@@ -186,10 +181,9 @@ def tests_transaction_is_affordable_else_statement():
 
 def test_apply():
     """Test the apply function."""
-    ownership_state = OwnershipState()
     currency_endowment = {"FET": 100}
     good_endowment = {"good_id": 2}
-    ownership_state.init(
+    ownership_state = OwnershipState(
         amount_by_currency_id=currency_endowment, quantities_by_good_id=good_endowment,
     )
     tx_message = TransactionMessage(
@@ -216,11 +210,10 @@ def test_apply():
 
 def test_transaction_update():
     """Test the transaction update when sending tokens."""
-    ownership_state = OwnershipState()
     currency_endowment = {"FET": 100}
     good_endowment = {"good_id": 20}
 
-    ownership_state.init(
+    ownership_state = OwnershipState(
         amount_by_currency_id=currency_endowment, quantities_by_good_id=good_endowment,
     )
     assert ownership_state.amount_by_currency_id == currency_endowment
@@ -248,10 +241,9 @@ def test_transaction_update():
 
 def test_transaction_update_receive():
     """Test the transaction update when receiving tokens."""
-    ownership_state = OwnershipState()
     currency_endowment = {"FET": 75}
     good_endowment = {"good_id": 30}
-    ownership_state.init(
+    ownership_state = OwnershipState(
         amount_by_currency_id=currency_endowment, quantities_by_good_id=good_endowment,
     )
     assert ownership_state.amount_by_currency_id == currency_endowment
