@@ -32,7 +32,6 @@ import pytest
 
 import aea
 from aea.configurations.base import PublicId
-from aea.connections.stub.connection import StubConnection
 from aea.mail.base import AEAConnectionError, Envelope, EnvelopeContext, Multiplexer
 from aea.protocols.default.message import DefaultMessage
 from aea.protocols.default.serialization import DefaultSerializer
@@ -40,19 +39,18 @@ from aea.protocols.default.serialization import DefaultSerializer
 from packages.fetchai.connections.local.connection import LocalNode, OEFLocalConnection
 
 from .conftest import (
-    DUMMY_CONNECTION_PUBLIC_ID,
-    DummyConnection,
     UNKNOWN_CONNECTION_PUBLIC_ID,
     UNKNOWN_PROTOCOL_PUBLIC_ID,
+    _make_dummy_connection,
+    _make_local_connection,
+    _make_stub_connection,
 )
 
 
 @pytest.mark.asyncio
 async def test_receiving_loop_terminated():
     """Test that connecting twice the multiplexer behaves correctly."""
-    multiplexer = Multiplexer(
-        [DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)]
-    )
+    multiplexer = Multiplexer([_make_dummy_connection()])
     multiplexer.connect()
 
     with unittest.mock.patch.object(aea.mail.base.logger, "debug") as mock_logger_debug:
@@ -65,9 +63,7 @@ async def test_receiving_loop_terminated():
 
 def test_connect_twice():
     """Test that connecting twice the multiplexer behaves correctly."""
-    multiplexer = Multiplexer(
-        [DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)]
-    )
+    multiplexer = Multiplexer([_make_dummy_connection()])
 
     assert not multiplexer.connection_status.is_connected
     multiplexer.connect()
@@ -85,10 +81,7 @@ def test_connect_twice_with_loop():
     thread_loop.start()
 
     try:
-        multiplexer = Multiplexer(
-            [DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)],
-            loop=running_loop,
-        )
+        multiplexer = Multiplexer([_make_dummy_connection()], loop=running_loop,)
 
         with unittest.mock.patch.object(
             aea.mail.base.logger, "debug"
@@ -110,24 +103,22 @@ def test_connect_twice_with_loop():
 @pytest.mark.asyncio
 async def test_connect_twice_a_single_connection():
     """Test that connecting twice a single connection behaves correctly."""
-    dummy_connection_id = PublicId("dummy_author", "dummy", "0.1.0")
-    multiplexer = Multiplexer([DummyConnection(connection_id=dummy_connection_id)])
+    connection = _make_dummy_connection()
+    multiplexer = Multiplexer([connection])
 
     assert not multiplexer.connection_status.is_connected
-    await multiplexer._connect_one(dummy_connection_id)
+    await multiplexer._connect_one(connection.connection_id)
     with unittest.mock.patch.object(aea.mail.base.logger, "debug") as mock_logger_debug:
-        await multiplexer._connect_one(dummy_connection_id)
+        await multiplexer._connect_one(connection.connection_id)
         mock_logger_debug.assert_called_with(
-            "Connection dummy_author/dummy:0.1.0 already established."
+            "Connection fetchai/dummy:0.1.0 already established."
         )
-        await multiplexer._disconnect_one(dummy_connection_id)
+        await multiplexer._disconnect_one(connection.connection_id)
 
 
 def test_multiplexer_connect_all_raises_error():
     """Test the case when the multiplexer raises an exception while connecting."""
-    multiplexer = Multiplexer(
-        [DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)]
-    )
+    multiplexer = Multiplexer([_make_dummy_connection()])
 
     with unittest.mock.patch.object(multiplexer, "_connect_all", side_effect=Exception):
         with pytest.raises(
@@ -145,15 +136,9 @@ def test_multiplexer_connect_one_raises_error_many_connections():
     input_file_path = d / "input_file.csv"
     output_file_path = d / "input_file.csv"
 
-    connection_1 = OEFLocalConnection(
-        "my_addr", node, connection_id=PublicId("fetchai", "local", "0.1.0")
-    )
-    connection_2 = StubConnection(
-        input_file_path,
-        output_file_path,
-        connection_id=PublicId("fetchai", "stub", "0.1.0"),
-    )
-    connection_3 = DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)
+    connection_1 = _make_local_connection("my_addr", node)
+    connection_2 = _make_stub_connection(input_file_path, output_file_path)
+    connection_3 = _make_dummy_connection()
     multiplexer = Multiplexer([connection_1, connection_2, connection_3])
 
     assert not connection_1.connection_status.is_connected
@@ -176,22 +161,20 @@ def test_multiplexer_connect_one_raises_error_many_connections():
 @pytest.mark.asyncio
 async def test_disconnect_twice_a_single_connection():
     """Test that connecting twice a single connection behaves correctly."""
-    dummy_connection_id = PublicId("dummy_author", "dummy", "0.1.0")
-    multiplexer = Multiplexer([DummyConnection(connection_id=dummy_connection_id)])
+    connection = _make_dummy_connection()
+    multiplexer = Multiplexer([_make_dummy_connection()])
 
     assert not multiplexer.connection_status.is_connected
     with unittest.mock.patch.object(aea.mail.base.logger, "debug") as mock_logger_debug:
-        await multiplexer._disconnect_one(dummy_connection_id)
+        await multiplexer._disconnect_one(connection.connection_id)
         mock_logger_debug.assert_called_with(
-            "Connection dummy_author/dummy:0.1.0 already disconnected."
+            "Connection fetchai/dummy:0.1.0 already disconnected."
         )
 
 
 def test_multiplexer_disconnect_all_raises_error():
     """Test the case when the multiplexer raises an exception while disconnecting."""
-    multiplexer = Multiplexer(
-        [DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)]
-    )
+    multiplexer = Multiplexer([_make_dummy_connection()])
     multiplexer.connect()
 
     assert multiplexer.connection_status.is_connected
@@ -220,15 +203,9 @@ async def test_multiplexer_disconnect_one_raises_error_many_connections():
         input_file_path = d / "input_file.csv"
         output_file_path = d / "input_file.csv"
 
-        connection_1 = OEFLocalConnection(
-            "my_addr", node, connection_id=PublicId("fetchai", "local", "0.1.0")
-        )
-        connection_2 = StubConnection(
-            input_file_path,
-            output_file_path,
-            connection_id=PublicId("fetchai", "stub", "0.1.0"),
-        )
-        connection_3 = DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)
+        connection_1 = _make_local_connection("my_addr", node)
+        connection_2 = _make_stub_connection(input_file_path, output_file_path)
+        connection_3 = _make_dummy_connection()
         multiplexer = Multiplexer([connection_1, connection_2, connection_3])
 
         assert not connection_1.connection_status.is_connected
@@ -262,9 +239,7 @@ async def test_multiplexer_disconnect_one_raises_error_many_connections():
 @pytest.mark.asyncio
 async def test_sending_loop_does_not_start_if_multiplexer_not_connected():
     """Test that the sending loop is stopped does not start if the multiplexer is not connected."""
-    multiplexer = Multiplexer(
-        [DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)]
-    )
+    multiplexer = Multiplexer([_make_dummy_connection()])
 
     with unittest.mock.patch.object(aea.mail.base.logger, "debug") as mock_logger_debug:
         await multiplexer._send_loop()
@@ -276,9 +251,7 @@ async def test_sending_loop_does_not_start_if_multiplexer_not_connected():
 @pytest.mark.asyncio
 async def test_sending_loop_cancelled():
     """Test the case when the sending loop is cancelled."""
-    multiplexer = Multiplexer(
-        [DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)]
-    )
+    multiplexer = Multiplexer([_make_dummy_connection()])
 
     multiplexer.connect()
 
@@ -293,7 +266,7 @@ async def test_sending_loop_cancelled():
 @pytest.mark.asyncio
 async def test_receiving_loop_raises_exception():
     """Test the case when an error occurs when a receive is started."""
-    connection = DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)
+    connection = _make_dummy_connection()
     multiplexer = Multiplexer([connection])
 
     with unittest.mock.patch("asyncio.wait", side_effect=Exception("a weird error.")):
@@ -312,7 +285,7 @@ async def test_receiving_loop_raises_exception():
 @pytest.mark.asyncio
 async def test_send_envelope_with_non_registered_connection():
     """Test that sending an envelope with an unregistered connection raises an exception."""
-    connection = DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)
+    connection = _make_dummy_connection()
     multiplexer = Multiplexer([connection])
     multiplexer.connect()
 
@@ -332,7 +305,7 @@ async def test_send_envelope_with_non_registered_connection():
 
 def test_send_envelope_error_is_logged_by_send_loop():
     """Test that the AEAConnectionError in the '_send' method is logged by the '_send_loop'."""
-    connection = DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)
+    connection = _make_dummy_connection()
     multiplexer = Multiplexer([connection])
     multiplexer.connect()
     fake_connection_id = UNKNOWN_CONNECTION_PUBLIC_ID
@@ -357,7 +330,7 @@ def test_send_envelope_error_is_logged_by_send_loop():
 
 def test_get_from_multiplexer_when_empty():
     """Test that getting an envelope from the multiplexer when the input queue is empty raises an exception."""
-    connection = DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)
+    connection = _make_dummy_connection()
     multiplexer = Multiplexer([connection])
 
     with pytest.raises(aea.mail.base.Empty):
@@ -373,11 +346,13 @@ def test_multiple_connection():
         connection_2_id = PublicId.from_str("author/local_2:0.1.0")
 
         connection_1 = OEFLocalConnection(
-            address_1, node, connection_id=connection_1_id
+            node, address=address_1, connection_id=connection_1_id
         )
+
         connection_2 = OEFLocalConnection(
-            address_2, node, connection_id=connection_2_id
+            node, address=address_2, connection_id=connection_2_id
         )
+
         multiplexer = Multiplexer([connection_1, connection_2])
 
         assert not connection_1.connection_status.is_connected
@@ -426,13 +401,12 @@ def test_send_message_no_supported_protocol():
     """Test the case when we send an envelope with a specific connection that does not support the protocol."""
     with LocalNode() as node:
         address_1 = "address_1"
-        connection_1_id = PublicId.from_str("author/local_1:0.1.0")
-        connection_1 = OEFLocalConnection(
+        public_id = PublicId.from_str("fetchai/my_private_protocol:0.1.0")
+        connection_1 = _make_local_connection(
             address_1,
             node,
-            connection_id=connection_1_id,
-            restricted_to_protocols={"my_private_protocol"},
-            excluded_protocols={"my_other_protocol"},
+            restricted_to_protocols={public_id},
+            excluded_protocols={public_id},
         )
         multiplexer = Multiplexer([connection_1])
 
@@ -449,8 +423,8 @@ def test_send_message_no_supported_protocol():
             multiplexer.put(envelope)
             time.sleep(0.5)
             mock_logger_warning.assert_called_with(
-                "Connection {} cannot handle protocol {}. Cannot send the message.".format(
-                    connection_1_id, protocol_id
+                "Connection {} cannot handle protocol {}. Cannot send the envelope.".format(
+                    connection_1.connection_id, protocol_id
                 )
             )
 
