@@ -41,7 +41,7 @@ def test_tac_message_instantiation():
         amount_by_currency_id={"FET": 10},
         tx_sender_fee=10,
         tx_counterparty_fee=10,
-        quantities_by_good_id={"good_1": 0, "good_2": 10},
+        quantities_by_good_id={"123": 0, "1234": 10},
         tx_nonce=1,
         tx_sender_signature=b"some_signature",
         tx_counterparty_signature=b"some_other_signature",
@@ -52,18 +52,19 @@ def test_tac_message_instantiation():
         performative=TacMessage.Performative.GAME_DATA,
         amount_by_currency_id={"FET": 10},
         exchange_params_by_currency_id={"FET": 10.0},
-        quantities_by_good_id={"good_1": 20, "good_2": 15},
-        utility_params_by_good_id={"good_1": 30.0, "good_2": 50.0},
+        quantities_by_good_id={"123": 20, "1234": 15},
+        utility_params_by_good_id={"123": 30.0, "1234": 50.0},
         tx_fee=20,
         agent_addr_to_name={"agent_1": "Agent one", "agent_2": "Agent two"},
-        good_id_to_name={"good_1": "First good", "good_2": "Second good"},
+        currency_id_to_name={"FET": "currency_name"},
+        good_id_to_name={"123": "First good", "1234": "Second good"},
         version_id="game_version_1",
     )
     assert TacMessage(
         performative=TacMessage.Performative.TRANSACTION_CONFIRMATION,
         tx_id="some_id",
         amount_by_currency_id={"FET": 10},
-        quantities_by_good_id={"good_1": 20, "good_2": 15},
+        quantities_by_good_id={"123": 20, "1234": 15},
     )
     assert TacMessage(
         performative=TacMessage.Performative.TAC_ERROR,
@@ -97,7 +98,7 @@ def test_tac_serialization():
         amount_by_currency_id={"FET": -10},
         tx_sender_fee=10,
         tx_counterparty_fee=10,
-        quantities_by_good_id={"good_1": 0, "good_2": 10},
+        quantities_by_good_id={"123": 0, "1234": 10},
         tx_nonce=1,
         tx_sender_signature=b"some_signature",
         tx_counterparty_signature=b"some_other_signature",
@@ -123,11 +124,12 @@ def test_tac_serialization():
         performative=TacMessage.Performative.GAME_DATA,
         amount_by_currency_id={"FET": 10},
         exchange_params_by_currency_id={"FET": 10.0},
-        quantities_by_good_id={"good_1": 20, "good_2": 15},
-        utility_params_by_good_id={"good_1": 30.0, "good_2": 50.0},
+        quantities_by_good_id={"123": 20, "1234": 15},
+        utility_params_by_good_id={"123": 30.0, "1234": 50.0},
         tx_fee=20,
         agent_addr_to_name={"agent_1": "Agent one", "agent_2": "Agent two"},
-        good_id_to_name={"good_1": "First good", "good_2": "Second good"},
+        currency_id_to_name={"FET": "currency_name"},
+        good_id_to_name={"123": "First good", "1234": "Second good"},
         version_id="game_version_1",
     )
     msg_bytes = TacSerializer().encode(msg)
@@ -139,7 +141,7 @@ def test_tac_serialization():
         performative=TacMessage.Performative.TRANSACTION_CONFIRMATION,
         tx_id="some_id",
         amount_by_currency_id={"FET": 10},
-        quantities_by_good_id={"good_1": 20, "good_2": 15},
+        quantities_by_good_id={"123": 20, "1234": 15},
     )
     msg_bytes = TacSerializer().encode(msg)
     actual_msg = TacSerializer().decode(msg_bytes)
