@@ -79,17 +79,23 @@ class TestCarPark:
         shutil.copytree(scripts_src, scripts_dst)
 
         result = self.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "init", "--author", AUTHOR], standalone_mode=False
+            cli,
+            [*CLI_LOG_OPTION, "init", "--local", "--author", AUTHOR],
+            standalone_mode=False,
         )
         assert result.exit_code == 0
 
         # create agent one and agent two
         result = self.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "create", self.agent_name_one], standalone_mode=False
+            cli,
+            [*CLI_LOG_OPTION, "create", "--local", self.agent_name_one],
+            standalone_mode=False,
         )
         assert result.exit_code == 0
         result = self.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "create", self.agent_name_two], standalone_mode=False
+            cli,
+            [*CLI_LOG_OPTION, "create", "--local", self.agent_name_two],
+            standalone_mode=False,
         )
         assert result.exit_code == 0
 
@@ -99,14 +105,20 @@ class TestCarPark:
 
         result = self.runner.invoke(
             cli,
-            [*CLI_LOG_OPTION, "add", "connection", "fetchai/oef:0.1.0"],
+            [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/oef:0.1.0"],
             standalone_mode=False,
         )
         assert result.exit_code == 0
 
         result = self.runner.invoke(
             cli,
-            [*CLI_LOG_OPTION, "add", "skill", "fetchai/carpark_detection:0.1.0"],
+            [
+                *CLI_LOG_OPTION,
+                "add",
+                "--local",
+                "skill",
+                "fetchai/carpark_detection:0.1.0",
+            ],
             standalone_mode=False,
         )
         assert result.exit_code == 0
@@ -116,7 +128,7 @@ class TestCarPark:
         )
         assert result.exit_code == 0
 
-        # Load the agent yaml file and manually insert the things we need
+        # Load the skill yaml file and manually insert the things we need
         yaml_path = os.path.join(
             "vendor", "fetchai", "skills", "carpark_detection", "skill.yaml"
         )
@@ -138,6 +150,26 @@ class TestCarPark:
         with open(yaml_path, "w") as f:
             f.write(whole_file)
 
+        # Load the agent yaml file and manually insert the things we need (ledger APIs)
+        file = open("aea-config.yaml", mode="r")
+
+        # read all lines at once
+        whole_file = file.read()
+
+        # add in the ledger address
+        find_text = "ledger_apis: {}"
+        replace_text = """ledger_apis:
+        fetchai:
+            network: testnet"""
+
+        whole_file = whole_file.replace(find_text, replace_text)
+
+        # close the file
+        file.close()
+
+        with open("aea-config.yaml", "w") as f:
+            f.write(whole_file)
+
         os.chdir(self.t)
 
         # Setup Agent two
@@ -146,14 +178,20 @@ class TestCarPark:
 
         result = self.runner.invoke(
             cli,
-            [*CLI_LOG_OPTION, "add", "connection", "fetchai/oef:0.1.0"],
+            [*CLI_LOG_OPTION, "add", "--local", "connection", "fetchai/oef:0.1.0"],
             standalone_mode=False,
         )
         assert result.exit_code == 0
 
         result = self.runner.invoke(
             cli,
-            [*CLI_LOG_OPTION, "add", "skill", "fetchai/carpark_client:0.1.0"],
+            [
+                *CLI_LOG_OPTION,
+                "add",
+                "--local",
+                "skill",
+                "fetchai/carpark_client:0.1.0",
+            ],
             standalone_mode=False,
         )
         assert result.exit_code == 0
