@@ -65,13 +65,17 @@ class TestEchoSkill:
         shutil.copytree(packages_src, packages_dst)
 
         result = self.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "init", "--author", AUTHOR], standalone_mode=False
+            cli,
+            [*CLI_LOG_OPTION, "init", "--local", "--author", AUTHOR],
+            standalone_mode=False,
         )
         assert result.exit_code == 0
 
         # create agent
         result = self.runner.invoke(
-            cli, [*CLI_LOG_OPTION, "create", self.agent_name], standalone_mode=False
+            cli,
+            [*CLI_LOG_OPTION, "create", "--local", self.agent_name],
+            standalone_mode=False,
         )
         assert result.exit_code == 0
         agent_dir_path = os.path.join(self.t, self.agent_name)
@@ -85,12 +89,12 @@ class TestEchoSkill:
             "version": 1,
             "loggers": {"aea.echo_skill": {"level": "CRITICAL"}},
         }
-        yaml.safe_dump(aea_config.json, open(aea_config_path, "w"))
+        yaml.safe_dump(dict(aea_config.json), open(aea_config_path, "w"))
 
         # add skills
         result = self.runner.invoke(
             cli,
-            [*CLI_LOG_OPTION, "add", "skill", "fetchai/echo:0.1.0"],
+            [*CLI_LOG_OPTION, "add", "--local", "skill", "fetchai/echo:0.1.0"],
             standalone_mode=False,
         )
         assert result.exit_code == 0
