@@ -17,46 +17,42 @@
 #
 # ------------------------------------------------------------------------------
 """This module contains the tests for the protocol generator."""
-
+import filecmp
 import inspect
 import logging
 import os
 import shutil
+import subprocess  # nosec
+import sys
 import tempfile
 import time
+from pathlib import Path
 from threading import Thread
 from typing import Optional
 from unittest import TestCase, mock
 
 import pytest
 
-import yaml
-
-from aea import AEA_DIR
-from aea.aea import AEA
+from aea.aea_builder import AEABuilder
 from aea.configurations.base import (
-    ProtocolConfig,
+    ComponentType,
     ProtocolId,
+    ProtocolSpecification,
     ProtocolSpecificationParseError,
     PublicId,
 )
+from aea.configurations.loader import ConfigLoader
 from aea.crypto.fetchai import FETCHAI
 from aea.crypto.helpers import FETCHAI_PRIVATE_KEY_FILE
-from aea.crypto.ledger_apis import LedgerApis
-from aea.crypto.wallet import Wallet
-from aea.identity.base import Identity
 from aea.mail.base import Envelope
-from aea.protocols.base import Message, Protocol
+from aea.protocols.base import Message
 from aea.protocols.generator import (
     ProtocolGenerator,
     _is_composition_type_with_custom_type,
     _specification_type_to_python_type,
     _union_sub_type_to_protobuf_variable_name,
 )
-from aea.registries.base import Resources
-from aea.skills.base import Handler, Skill, SkillContext
-
-from packages.fetchai.connections.oef.connection import OEFConnection
+from aea.skills.base import Handler, SkillContext
 
 from tests.data.generator.t_protocol.message import (  # type: ignore
     TProtocolMessage,
@@ -66,6 +62,7 @@ from tests.data.generator.t_protocol.serialization import (  # type: ignore
 )
 
 from ..common.click_testing import CliRunner
+from ..conftest import ROOT_DIR
 
 logger = logging.getLogger("aea")
 logging.basicConfig(level=logging.INFO)
@@ -75,7 +72,7 @@ HOST = "127.0.0.1"
 PORT = 10000
 
 
-class TestGenerateProtocol:
+class TestEndToEndGenerator:
     """Test that the generating a protocol works correctly in correct preconditions."""
 
     @pytest.fixture(autouse=True)
@@ -86,11 +83,106 @@ class TestGenerateProtocol:
     def setup_class(cls):
         """Set the test up."""
         cls.runner = CliRunner()
-        cls.agent_name = "agent_1"
         cls.cwd = os.getcwd()
         cls.t = tempfile.mkdtemp()
         os.chdir(cls.t)
 
+    def test_compare_latest_generator_output_with_test_protocol(self):
+        """Test that the "t_protocol" test protocol matches with what the latest generator generates based on the specification."""
+        # check protoc is installed
+        res = shutil.which("protoc")
+        if res is None:
+            pytest.skip(
+                "Please install protocol buffer first! See the following link: https://developers.google.com/protocol-buffers/"
+            )
+
+        # Specification
+        protocol_name = "t_protocol"
+        path_to_specification = os.path.join(
+            self.cwd, "tests", "data", "sample_specification.yaml"
+        )
+        path_to_generated_protocol = self.t
+        path_to_original_protocol = os.path.join(
+            self.cwd, "tests", "data", "generator", protocol_name
+        )
+        path_to_package = "tests.data.generator."
+
+        # Load the config
+        config_loader = ConfigLoader(
+            "protocol-specification_schema.json", ProtocolSpecification
+        )
+        protocol_specification = config_loader.load_protocol_specification(
+            open(path_to_specification)
+        )
+
+        # Generate the protocol
+        protocol_generator = ProtocolGenerator(
+            protocol_specification,
+            path_to_generated_protocol,
+            path_to_protocol_package=path_to_package,
+        )
+        protocol_generator.generate()
+
+        # Apply black
+        try:
+            subp = subprocess.Popen(  # nosec
+                [
+                    sys.executable,
+                    "-m",
+                    "black",
+                    os.path.join(path_to_generated_protocol, protocol_name),
+                    "--quiet",
+                ]
+            )
+            subp.wait(10.0)
+        finally:
+            poll = subp.poll()
+            if poll is None:  # pragma: no cover
+                subp.terminate()
+                subp.wait(5)
+
+        # compare __init__.py
+        init_file_generated = Path(self.t, protocol_name, "__init__.py")
+        init_file_original = Path(path_to_original_protocol, "__init__.py",)
+        assert filecmp.cmp(init_file_generated, init_file_original)
+
+        # # compare protocol.yaml
+        # protocol_yaml_file_generated = Path(self.t, protocol_name, "protocol.yaml")
+        # protocol_yaml_file_original = Path(path_to_original_protocol, "protocol.yaml",)
+        # assert filecmp.cmp(protocol_yaml_file_generated, protocol_yaml_file_original)
+
+        # # compare message.py
+        # message_file_generated = Path(self.t, protocol_name, "message.py")
+        # message_file_original = Path(path_to_original_protocol, "message.py",)
+        # assert filecmp.cmp(message_file_generated, message_file_original)
+
+        # # compare serialization.py
+        # serialization_file_generated = Path(self.t, protocol_name, "serialization.py")
+        # serialization_file_original = Path(
+        #     path_to_original_protocol, "serialization.py",
+        # )
+        # assert filecmp.cmp(serialization_file_generated, serialization_file_original)
+
+        # # compare .proto
+        # proto_file_generated = Path(
+        #     self.t, protocol_name, "{}.proto".format(protocol_name)
+        # )
+        # proto_file_original = Path(
+        #     path_to_original_protocol, "{}.proto".format(protocol_name),
+        # )
+        # assert filecmp.cmp(proto_file_generated, proto_file_original)
+
+        # # compare _pb2.py
+        # pb2_file_generated = Path(
+        #     self.t, protocol_name, "{}_pb2.py".format(protocol_name)
+        # )
+        # with open(ROOT_DIR + "/x_pb2.py", "w") as fp:
+        #     fp.write(pb2_file_generated.read_text())
+        # pb2_file_original = Path(
+        #     path_to_original_protocol, "{}_pb2.py".format(protocol_name),
+        # )
+        # assert filecmp.cmp(pb2_file_generated, pb2_file_original)
+
     def test_generated_protocol_serialisation_ct(self):
         """Test that a generated protocol's serialisation + deserialisation work correctly."""
         # create a message with pt content
@@ -165,63 +257,35 @@ class TestGenerateProtocol:
 
     def test_generated_protocol_end_to_end(self):
         """Test that a generated protocol could be used in exchanging messages between two agents."""
-        # AEA components
-        ledger_apis = LedgerApis({}, FETCHAI)
-
-        wallet_1 = Wallet({FETCHAI: FETCHAI_PRIVATE_KEY_FILE})
-        wallet_2 = Wallet({FETCHAI: FETCHAI_PRIVATE_KEY_FILE})
-
-        identity_1 = Identity(
-            name="my_aea_1",
-            address=wallet_1.addresses.get(FETCHAI),
-            default_address_key=FETCHAI,
+        builder_1 = AEABuilder()
+        builder_1.set_name("my_aea_1")
+        builder_1.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
+        builder_1.set_default_ledger(FETCHAI)
+        builder_1.add_component(
+            ComponentType.PROTOCOL,
+            Path(ROOT_DIR, "tests", "data", "generator", "t_protocol"),
+            skip_consistency_check=True,
         )
-        identity_2 = Identity(
-            name="my_aea_2",
-            address=wallet_2.addresses.get(FETCHAI),
-            default_address_key=FETCHAI,
+        builder_1.add_connection(
+            Path(ROOT_DIR, "packages", "fetchai", "connections", "oef")
         )
 
-        oef_connection_1 = OEFConnection(
-            address=identity_1.address, oef_addr=HOST, oef_port=PORT
+        builder_2 = AEABuilder()
+        builder_2.set_name("my_aea_2")
+        builder_2.add_private_key(FETCHAI, FETCHAI_PRIVATE_KEY_FILE)
+        builder_2.set_default_ledger(FETCHAI)
+        builder_2.add_component(
+            ComponentType.PROTOCOL,
+            Path(ROOT_DIR, "tests", "data", "generator", "t_protocol"),
+            skip_consistency_check=True,
         )
-        oef_connection_2 = OEFConnection(
-            address=identity_2.address, oef_addr=HOST, oef_port=PORT
-        )
-
-        resources_1 = Resources()
-        resources_2 = Resources()
-
-        # add generated protocols to resources
-        generated_protocol_configuration = ProtocolConfig.from_json(
-            yaml.safe_load(
-                open(
-                    os.path.join(
-                        self.cwd,
-                        "tests",
-                        "data",
-                        "generator",
-                        "t_protocol",
-                        "protocol.yaml",
-                    )
-                )
-            )
-        )
-        generated_protocol = Protocol(
-            TProtocolMessage.protocol_id,
-            TProtocolSerializer(),
-            generated_protocol_configuration,
-        )
-        resources_1.protocol_registry.register(
-            TProtocolMessage.protocol_id, generated_protocol
-        )
-        resources_2.protocol_registry.register(
-            TProtocolMessage.protocol_id, generated_protocol
+        builder_2.add_connection(
+            Path(ROOT_DIR, "packages", "fetchai", "connections", "oef")
         )
 
         # create AEAs
-        aea_1 = AEA(identity_1, [oef_connection_1], wallet_1, ledger_apis, resources_1)
-        aea_2 = AEA(identity_2, [oef_connection_2], wallet_2, ledger_apis, resources_2)
+        aea_1 = builder_1.build(connection_ids=[PublicId.from_str("fetchai/oef:0.1.0")])
+        aea_2 = builder_2.build(connection_ids=[PublicId.from_str("fetchai/oef:0.1.0")])
 
         # message 1
         message = TProtocolMessage(
@@ -237,8 +301,8 @@ class TestGenerateProtocol:
         )
         encoded_message_in_bytes = TProtocolSerializer().encode(message)
         envelope = Envelope(
-            to=identity_2.address,
-            sender=identity_1.address,
+            to=aea_2.identity.address,
+            sender=aea_1.identity.address,
             protocol_id=TProtocolMessage.protocol_id,
             message=encoded_message_in_bytes,
         )
@@ -261,19 +325,20 @@ class TestGenerateProtocol:
         agent_1_handler = Agent1Handler(
             skill_context=SkillContext(aea_1.context), name="fake_skill"
         )
-        resources_1.handler_registry.register(
+        aea_1.resources._handler_registry.register(
             (
                 PublicId.from_str("fetchai/fake_skill:0.1.0"),
                 TProtocolMessage.protocol_id,
             ),
             agent_1_handler,
         )
+
         agent_2_handler = Agent2Handler(
             encoded_messsage=encoded_message_2_in_bytes,
             skill_context=SkillContext(aea_2.context),
             name="fake_skill",
         )
-        resources_2.handler_registry.register(
+        aea_2.resources._handler_registry.register(
             (
                 PublicId.from_str("fetchai/fake_skill:0.1.0"),
                 TProtocolMessage.protocol_id,
@@ -281,17 +346,6 @@ class TestGenerateProtocol:
             agent_2_handler,
         )
 
-        # add error skill to AEAs
-        error_skill_1 = Skill.from_dir(
-            os.path.join(AEA_DIR, "skills", "error"), aea_1.context
-        )
-        resources_1.add_skill(error_skill_1)
-
-        error_skill_2 = Skill.from_dir(
-            os.path.join(AEA_DIR, "skills", "error"), aea_2.context
-        )
-        resources_2.add_skill(error_skill_2)
-
         # Start threads
         t_1 = Thread(target=aea_1.start)
         t_2 = Thread(target=aea_2.start)
@@ -416,8 +470,8 @@ class ProtocolGeneratorTestCase(TestCase):
     def setUp(self):
         protocol_specification = mock.Mock()
         protocol_specification.name = "name"
-        ProtocolGenerator._setup = mock.Mock()
-        self.protocol_generator = ProtocolGenerator(protocol_specification)
+        with mock.patch.object(ProtocolGenerator, "_setup"):
+            self.protocol_generator = ProtocolGenerator(protocol_specification)
 
     @mock.patch(
         "aea.protocols.generator._get_sub_types_of_compositional_types",
