@@ -18,6 +18,7 @@
 # ------------------------------------------------------------------------------
 """The test error skill module contains the tests of the error skill."""
 
+import logging
 import os
 import time
 from pathlib import Path
@@ -31,7 +32,7 @@ from aea.identity.base import Identity
 from aea.mail.base import Envelope
 from aea.protocols.default.message import DefaultMessage
 from aea.protocols.default.serialization import DefaultSerializer
-from aea.registries.base import Resources
+from aea.registries.resources import Resources
 from aea.skills.base import SkillContext
 from aea.skills.error.handlers import ErrorHandler
 
@@ -40,7 +41,7 @@ from packages.fetchai.protocols.fipa.message import FipaMessage
 from packages.fetchai.protocols.fipa.serialization import FipaSerializer
 from packages.fetchai.protocols.oef_search.message import OefSearchMessage
 
-from ..conftest import CUR_PATH, DUMMY_CONNECTION_PUBLIC_ID, DummyConnection
+from ..conftest import CUR_PATH, _make_dummy_connection
 
 
 class TestSkillError:
@@ -55,7 +56,7 @@ class TestSkillError:
         cls.ledger_apis = LedgerApis({}, FETCHAI)
         cls.agent_name = "Agent0"
 
-        cls.connection = DummyConnection(connection_id=DUMMY_CONNECTION_PUBLIC_ID)
+        cls.connection = _make_dummy_connection()
         cls.connections = [cls.connection]
         cls.identity = Identity(cls.agent_name, address=cls.wallet.addresses[FETCHAI])
         cls.address = cls.identity.address
@@ -69,6 +70,10 @@ class TestSkillError:
             is_programmatic=False,
         )
         cls.skill_context = SkillContext(cls.my_aea._context)
+        logger_name = "aea.{}.skills.{}.{}".format(
+            cls.my_aea._context.agent_name, "fetchai", "error"
+        )
+        cls.skill_context._logger = logging.getLogger(logger_name)
         cls.my_error_handler = ErrorHandler(
             name="error", skill_context=cls.skill_context
         )
